/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.guacamole.rest.tunnel;

import org.apache.guacamole.net.auth.AuthenticatedUser;
import org.apache.guacamole.tunnel.UserTunnel;

/**
 * Factory which creates resources that expose the contents of a given
 * tunnel.
 */
public interface TunnelResourceFactory {

    /**
     * Creates a new TunnelResource which exposes the contents of the
     * given tunnel.
     *
     * @param authenticatedUser
     *     The user that is accessing the resource.
     *
     * @param tunnel
     *     The tunnel whose contents should be exposed.
     *
     * @return
     *     A new TunnelResource which exposes the contents of the given tunnel.
     */
    TunnelResource create(AuthenticatedUser authenticatedUser, UserTunnel tunnel);

}
